<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Event_Upcomingevent extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_event_upcomingevent';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Event Upcomingevent', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_event_upcoming_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_upcoming_tagline',
            [
                'label'       => esc_html__( 'Tagline', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        //List
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_event_upcoming_list_title',
            [
                'label'       => esc_html__( 'Center Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Business Event', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_event_upcoming_list_time',
            [
                'label'       => esc_html__( 'Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Start 11:00 am - 1:00 pm', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_event_upcoming_list_location',
            [
                'label'       => esc_html__( 'Location', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Start 11:00 am - 1:00 pm', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_event_upcoming_list_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Know More', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_event_upcoming_list_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_event_upcoming_list_image',
            [
				'label'       => esc_html__( 'Center Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
			]
        );
        
        $this->add_control(
            'lcp_event_upcoming_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_event_upcoming_list_title'  => esc_html__( 'Event', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_event_upcoming_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_event_upcoming_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // tegline Style
        $this->add_control( 
			'lcp_event_upcoming_style_tegline',
			[
				'label' => esc_html__( 'Tegline', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_upcoming_style_tegline_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h3'
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_style_tegline_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // tegline Style
        $this->add_control( 
			'lcp_event_upcoming_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_upcoming_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h2'
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_style_extra_color',
            [
                'label'     => esc_html__( 'Extra', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2:after' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-heading-style21 > h2:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_event_upcoming_list_style_tab', 
            [
                'label' => esc_html__( 'Event Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
		// tegline Style
        $this->add_control( 
			'lcp_event_upcoming_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_upcoming_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-eventbox-timer-wrapper > h5'
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_list_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-eventbox-timer-wrapper > h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // tegline Style
        $this->add_control( 
			'lcp_event_upcoming_list_style_time_location',
			[
				'label' => esc_html__( 'Time & Location', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_upcoming_list_style_time_location_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-eventtime > p, .lc-eventlocation> p'
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_list_style_time_location_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-eventtime > p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-eventlocation> p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control( 
			'lcp_event_upcoming_list_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_upcoming_list_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-knowbtn-style21 > a'
            ]
        );
		
		
		$this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_event_upcoming_list_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_event_upcoming_list_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-knowbtn-style21',
            ]
        );
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_event_upcoming_list_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21:hover > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_event_upcoming_list_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-knowbtn-style21:hover',
            ]
        );
		$this->add_control(
            'lcp_event_upcoming_list_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-knowbtn-style21:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_event_upcoming_style_nav', 
            [
                'label' => esc_html__( 'Navigation', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
		// tegline Style
        $this->add_control( 
			'lcp_event_upcoming_list_style_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'lcp_event_upcoming_list_style_normal_color',
            [
                'label'     => esc_html__( 'Icon Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-prev > svg > .s0' => 'fill: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-next > svg > .s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_list_style_normal_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-prev' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-next' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        
        // tegline Style
        $this->add_control( 
			'lcp_event_upcoming_list_style_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'lcp_event_upcoming_list_style_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-prev:hover > svg > .s0' => 'fill: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-next:hover > svg > .s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_event_upcoming_list_style_hover_bgcolor', 
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-event-slider-btn > .swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
		
		
		
		
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-event-section lc-event-section-style21">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style21">';
                                if(!empty($settings['lcp_event_upcoming_tagline'])){
                                    echo '<h3>'.esc_html($settings['lcp_event_upcoming_tagline']).'</h3>';
                                }
                                if(!empty($settings['lcp_event_upcoming_title'])){
                                    echo '<h2>'.esc_html($settings['lcp_event_upcoming_title']).'</h2>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="lc-eventslider-wrapper lc-eventslider-wrapper-style21">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-eventslider-wrappers lc-eventslider-wrappers-style21">
                                    <div class="swiper lc-eventslider-style21">
                                        <div class="swiper-wrapper">';
                                            if(!empty($settings['lcp_event_upcoming_list'])){
                                                foreach($settings['lcp_event_upcoming_list'] as $list){
                                                    echo '<div class="swiper-slide">
                                                        <div class="lc-eventbox-wrapper">';
                                                            if(!empty($list['lcp_event_upcoming_list_image']['url'])){
                                                                echo '<img src="'.esc_url($list['lcp_event_upcoming_list_image']['url']).'" alt="'.esc_attr('event-img', 'leadcapture').'">';
                                                            }
                                                            echo '<div class="lc-eventbox-timer-wrapper">';
                                                                if(!empty($list['lcp_event_upcoming_list_title'])){
                                                                    echo '<h5>'.esc_html($list['lcp_event_upcoming_list_title']).'</h5>';
                                                                }
                                                                echo '<div class="lc-eventtimer-box">';
                                                                    if(!empty($list['lcp_event_upcoming_list_time'])){
                                                                        echo '<div class="lc-eventtime">
                                                                            <img src="'.LEAD_CAPTURE_URL.'/public/images/timer.png">
                                                                            <p>'.esc_html($list['lcp_event_upcoming_list_time']).'</p>
                                                                        </div>';
                                                                    }
                                                                    if(!empty($list['lcp_event_upcoming_list_location'])){
                                                                        echo '<div class="lc-eventlocation">
                                                                            <img src="'.LEAD_CAPTURE_URL.'/public/images/location.png">
                                                                            <p>South Street, London</p>
                                                                        </div>';
                                                                    }
                                                                    if(!empty($list['lcp_event_upcoming_list_btn_title'])){
                                                                        echo '<div class="lc-btn lc-btn-style21 lc-knowbtn-style21">
                                                                            <a href="'.esc_url($list['lcp_event_upcoming_list_btn_link']).'">'.esc_html($list['lcp_event_upcoming_list_btn_title']).'</a> 
                                                                        </div>';
                                                                    }
                                                                echo '</div>
                                                            </div>
                                                        </div>
                                                    </div>';
                                                }
                                            } 
                                        echo '</div>
                                    </div>
                                    <div class="lc-event-slider-btn">
                                        <div class="swiper-button-next" tabindex="0" role="button" aria-label="Next slide" aria-controls="swiper-wrapper-674d35597aa96584">
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11" height="17">
                                                <title>Shape 12</title>
                                                <path id="Shape 12" class="s0" d="m9 9q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z"></path>
                                            </svg>
                                        </div>
                                        <div class="swiper-button-prev" tabindex="0" role="button" aria-label="Previous slide" aria-controls="swiper-wrapper-674d35597aa96584">
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11" height="17">
                                                <title>Shape 12</title>
                                                <path id="Shape 12" class="s0" d="m2.2 8.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z"></path>
                                            </svg>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}