<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Gardeners_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_gardeners_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Gardeners Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_gardeners_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
		$this->add_control(
            'lcp_gardeners_banner_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_btn_name',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_section',
            [
				'label'       => esc_html__( 'Section Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
		$this->end_controls_section();
		//Newsletter
		$this->start_controls_section(
            'lcp_gardeners_banner_newsletter_div', 
            [
               'label' => esc_html__( 'Newsletter', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_gardeners_banner_newsletter_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_newsletter_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_newsletter_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        //Newsletter
		$this->start_controls_section(
            'lcp_gardeners_banner_right_div', 
            [
               'label' => esc_html__( 'Right Side Content', 'leadcapture' ),
            ]
        ); 
        // Heading Style
        $this->add_control(
			'lcp_gardeners_banner_right',
			[
				'label' => esc_html__( 'First Section', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_control(
            'lcp_gardeners_banner_right_fdiv_icon',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_fdiv_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_fdiv_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_gardeners_banner_right_fdiv',
			[
				'label' => esc_html__( 'Other Icon & Image', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_control(
            'lcp_gardeners_banner_right_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_icon_one',
            [
				'label'       => esc_html__( 'Icon One', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_icon_two',
            [
				'label'       => esc_html__( 'Icon Two', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        
        // Widget Style
        $this->start_controls_section(
            'lcp_gardeners_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardeners_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style20 > h1'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style20 > h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardeners_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style20 > p'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style20 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardeners_banner_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_gardeners_banner_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_gardeners_banner_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_gardeners_banner_style_button_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style20',
            ]
        );
		$this->add_control(
            'lcp_gardeners_banner_style_button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_gardeners_banner_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_gardeners_banner_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20:hover > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_gardeners_banner_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20:before' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style20:hover:hover',
            ]
        );
		$this->add_control(
            'lcp_gardeners_banner_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style20:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        $this->end_controls_section();
        
        
        // Widget Style
        $this->start_controls_section(
            'lcp_gardeners_banner_newsletter_style_tab', 
            [
                'label' => esc_html__( 'Newsletter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardeners_banner_newsletter_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_newsletter_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subscribe-form-style20 > h2'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_newsletter_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subscribe-form-style20 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardeners_banner_newsletter_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_newsletter_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subscribe-form-style20 > p'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_newsletter_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subscribe-form-style20 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
			'lcp_gardeners_banner_newsletter_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_newsletter_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-sub-form-style20 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_newsletter_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-sub-form-style20 button'
            ]
        );
        $this->end_controls_section();
        
		// Widget Style
        $this->start_controls_section(
            'lcp_gardeners_banner_right_style_tab', 
            [
                'label' => esc_html__( 'Icon Box Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardeners_banner_right_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_right_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bannericon-bg-text-style20 > .lc-bannericon-text-style20 > h3'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-bg-text-style20 > .lc-bannericon-text-style20 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardeners_banner_right_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardeners_banner_right_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bannericon-bg-text-style20 > .lc-bannericon-text-style20 > p'
            ]
        );
        $this->add_control(
            'lcp_gardeners_banner_right_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-bg-text-style20 > .lc-bannericon-text-style20 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardeners_banner_right_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_gardeners_banner_right_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-bg-text-style20 > .lcbannericon-bg-style20' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $style = !empty($settings['lcp_gardeners_banner_section']['url']) ? 'style="background: url('.esc_url($settings['lcp_gardeners_banner_section']['url']).');"' : '';
		    echo '<div class="lc-banner-section lc-banner-section-style20" '.$style.'>
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-text lc-banner-text-style20">';
                                if(!empty($settings['lcp_gardeners_banner_heading'])){
                                    echo '<h1>';
                                        printf($settings['lcp_gardeners_banner_heading']);
                                    echo '</h1>';
                                }
                                if(!empty($settings['lcp_gardeners_banner_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_gardeners_banner_desc']).'</p>';
                                }
                                if(!empty($settings['lcp_gardeners_banner_btn_name'])){
                                    echo '<div class="lc-btn lc-btn-style20">
                                        <a href="'.esc_url($settings['lcp_gardeners_banner_btn_link']).'">'.esc_html($settings['lcp_gardeners_banner_btn_name']).'
                                            <img src="'.LEAD_CAPTURE_URL.'/public/images/Arrow1.png" alt="'.esc_attr('arrow', 'leadcapture').'">
                                        </a>
                                    </div>';
                                }
                                echo '<div class="lc-form-arrow-style20">
                                    <img src="'.LEAD_CAPTURE_URL.'/public/images/form-arrow.png" alt="'.esc_attr('form-arrow', 'leadcapture').'">
                                </div>
                                <div class="lc-subscribe-form lc-subscribe-form-style20">';
                                    if(!empty($settings['lcp_gardeners_banner_newsletter_heading'])){
                                        echo '<h2>'.esc_html($settings['lcp_gardeners_banner_newsletter_heading']).'</h2>';
                                    }
                                    if(!empty($settings['lcp_gardeners_banner_newsletter_desc'])){
                                        echo '<p>'.esc_html($settings['lcp_gardeners_banner_newsletter_desc']).'</p>';
                                    }
                                    echo '<div class="lc-sub-form lc-sub-form-style20">';
                                        if(!empty($settings['lcp_gardeners_banner_newsletter_shortcode'])){
                                            echo do_shortcode($settings['lcp_gardeners_banner_newsletter_shortcode']);
                                        }
                                    echo '</div>
                                    <div class="lc-formbg-shape">
                                        <img src="'.LEAD_CAPTURE_URL.'/public/images/banner-form-icon.png" alt="'.esc_attr('arrow', 'leadcapture').'">
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-wrapper-style20">
                                <div class="lc-banner-image lc-banner-image-style20">';
                                    if(!empty($settings['lcp_gardeners_banner_right_image']['url'])){
                                        echo '<img src="'.esc_url($settings['lcp_gardeners_banner_right_image']['url']).'" class="right-img">';
                                    }
                                    echo '<div class="lc-banner-icon lc-banner-icon-style20">';
                                        if(!empty($settings['lcp_gardeners_banner_right_icon_one']['url'])){
                                            echo '<div class="lc-bannericon-bg-style20">
                                                <img src="'.esc_url($settings['lcp_gardeners_banner_right_icon_one']['url']).'" alt="'.esc_attr('gard-banner-icon1', 'leadcapture').'" class="lc-gbanner-icon1">
                                            </div>';
                                        }
                                        if(!empty($settings['lcp_gardeners_banner_right_icon_two']['url'])){
                                            echo '<div class="lc-bannericon-bg-style20">
                                                <img src="'.esc_url($settings['lcp_gardeners_banner_right_icon_two']['url']).'" alt="'.esc_attr('gard-banner-icon2', 'leadcapture').'" class="lc-gbanner-icon1">
                                            </div>';
                                        }
                                        if(!empty($settings['lcp_gardeners_banner_right_fdiv_icon']['url']) || !empty($settings['lcp_gardeners_banner_right_fdiv_heading']) || !empty($settings['lcp_gardeners_banner_right_fdiv_desc'])){
                                            echo '<div class="lc-bannericon-bg-style20 lc-bannericon-bg-text-style20">';
                                                if(!empty($settings['lcp_gardeners_banner_right_fdiv_icon']['url'])){
                                                    echo '<div class="lcbannericon-bg-style20">
                                                        <img src="'.esc_url($settings['lcp_gardeners_banner_right_fdiv_icon']['url']).'" alt="'.esc_attr('gard-banner-icon3', 'leadcapture').'" class="lc-gbanner-icon3">
                                                    </div>';
                                                }
                                                echo '<div class="lc-bannericon-text-style20">';
                                                    if(!empty($settings['lcp_gardeners_banner_right_fdiv_heading'])){
                                                        echo '<h3>'.esc_html($settings['lcp_gardeners_banner_right_fdiv_heading']).'</h3>';
                                                    }
                                                    if(!empty($settings['lcp_gardeners_banner_right_fdiv_desc'])){
                                                        echo '<p>'.esc_html($settings['lcp_gardeners_banner_right_fdiv_desc']).'</p>';
                                                    }
                                                echo '</div>
                                            </div>';
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}