<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Security_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_security_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Security Testimonials', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_security_testimonials_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_security_testimonials_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_testimonials_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_testimonials_list_testi',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_testimonials_list_image',
            [
				'label'       => esc_html__( 'Author Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			] 
        );
        $this->add_control(
            'lcp_security_testimonials_list',
            [
                'label'       => esc_html__( 'Add Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_security_testimonials_list_author}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_security_testimonials_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_testimonials_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style29 > h2'
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style29 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_style_author',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_testimonials_style_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-name-style29 > h5'
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_style_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-name-style29 > h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_style_designation',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_testimonials_style_designation_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-name-style29 > h6'
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_style_designation_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-name-style29 > h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_style_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_testimonials_style_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-para-style29 > p'
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_style_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-para-style29 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_security_testimonials_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-gallery-top > .lc-gallery-thumbs.lc-gallery-thumbs-style29 .swiper-slide.swiper-slide' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_style_boxbg_radius',
            [
                'label'     => esc_html__( 'Background Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-gallery-top.lc-gallery-top-style29' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_security_testimonials_nav_style', 
            [
                'label' => esc_html__( 'Navigation Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_nav_style_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_control(
            'lcp_security_testimonials_nav_style_normal_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-prev > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-next > svg > .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_nav_style_normal_bgcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-prev' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-next' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_testimonials_nav_style_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_control(
            'lcp_security_testimonials_nav_style_hover_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-prev:hover > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-next:hover > svg > .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_testimonials_nav_style_hover_bgcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_style_btn_radius',
            [
                'label'     => esc_html__( 'Left Arrove Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-prev' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_style_btn_right_radius',
            [
                'label'     => esc_html__( 'Right Arrove Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonialslider-wrapper-style29 > .swiper-button-next' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-style29">
                <div class="container">';
                    if(!empty($settings['lcp_security_testimonials_title'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-sm-12 col-md-12">
                                <div class="lc-heading-wrapper lc-heading-style29">
                                    <h2>'.esc_html($settings['lcp_security_testimonials_title']).'</h2>
                                </div>
                            </div>
                        </div>';
                    }
                    if(!empty($settings['lcp_security_testimonials_list'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-testimonialslider-wrapper lc-testimonialslider-wrapper-style29">
                                    <div class="swiper lc-gallery-top lc-gallery-top-style29">
                                        <div class="swiper-wrapper">';
                                            foreach($settings['lcp_security_testimonials_list'] as $list){
                                                echo '<div class="swiper-slide">
                                                    <div class="swiper-slide-container">
                                                        <div class="lc-test-wrapper-style29">
                                                            <div class="lc-test-para-style29">';
                                                                if(!empty($list['lcp_security_testimonials_list_testi'])){
                                                                    echo '<p>'.esc_html($list['lcp_security_testimonials_list_testi']).'</p>';
                                                                }
                                                                echo '<div class="lc-quote-img-style29">
                                                                    <img src="'.LEAD_CAPTURE_URL.'/public/images/quote-28.png" alt="'.esc_attr('quote-img', 'leadcapture').'">
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>';
                                            }
                                        echo '</div>
                                        <div class="swiper lc-gallery-thumbs lc-gallery-thumbs-style29">
                                            <div class="swiper-wrapper">';
                                                foreach($settings['lcp_security_testimonials_list'] as $list){
                                                    echo '<div class="swiper-slide">
                                                        <div class="swiper-slide-container">
                                                            <div class="lc-testimonial-img lc-testimonial-img-style29">';
                                                                if(!empty($list['lcp_security_testimonials_list_image']['url'])){
                                                                    echo '<img src="'.esc_url($list['lcp_security_testimonials_list_image']['url']).'" />';
                                                                }
                                                                echo '<div class="lc-test-name-style29">';
                                                                    if(!empty($list['lcp_security_testimonials_list_author'])){
                                                                        echo '<h5>'.esc_html($list['lcp_security_testimonials_list_author']).'</h5>';
                                                                    }
                                                                    if(!empty($list['lcp_security_testimonials_list_postion'])){
                                                                        echo '<h6>'.esc_html($list['lcp_security_testimonials_list_postion']).'</h6>';
                                                                    }
                                                                echo '</div>
                                                            </div>
                                                        </div>
                                                    </div>';
                                                }
                                            echo '</div>
                                        </div>
                                    </div>
                                    <div class="swiper-button-next">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="7" height="12" viewBox="0 0 7 12">
                                            <path class="cls-1" d="M6.807,5.532L1.51,0.194a0.649,0.649,0,0,0-.921,0L0.2,0.587a0.66,0.66,0,0,0,0,.928L4.647,6,0.194,10.485a0.661,0.661,0,0,0,0,.928l0.39,0.393a0.649,0.649,0,0,0,.921,0l5.3-5.343A0.666,0.666,0,0,0,6.807,5.532Z"/>
                                        </svg>
                                    </div>
                                    <div class="swiper-button-prev">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="7" height="12" viewBox="0 0 7 12">
                                            <path class="cls-1" d="M0.193,5.532l5.3-5.338a0.649,0.649,0,0,1,.921,0L6.8,0.587a0.66,0.66,0,0,1,0,.928L2.353,6l4.453,4.487a0.661,0.661,0,0,1,0,.928l-0.39.393a0.649,0.649,0,0,1-.921,0l-5.3-5.343A0.666,0.666,0,0,1,.193,5.532Z"/>
                                        </svg>                                      
                                    </div>
                                </div>
                            </div>
                        </div>';
                    }
                echo '</div>
            </div>';    
		}
	}
}