<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Tatto_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_tatto_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Tatto Testimonials', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_tatto_testi_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_tatto_testi_list_title',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Graham Hardacre', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_tatto_testi_list_postion',
            [
                'label'       => esc_html__( 'Desgination', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Ui/Ux Designer', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_tatto_testi_list_testi',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'lcp_tatto_testi_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_tatto_testi_list',
            [
                'label'       => esc_html__( 'Add New', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_tatto_testi_list_title'  => esc_html__( 'Graham Hardacre', 'leadcapture' ),
						'lcp_tatto_testi_list_postion'  => esc_html__( 'Ui/Ux Designer', 'leadcapture' ),
						'lcp_tatto_testi_list_testi'  => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_tatto_testi_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		//Widget Style
		$this->start_controls_section(
            'lcp_tatto_testi_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Author
        $this->add_control(
            'lcp_tatto_testi_style_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Typography', 'leadcapture'),
            'name'     => 'lcp_tatto_testi_style_author_typography',
            'selector' => '{{WRAPPER}} .lc-test-name-style2 h5',
            ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_author_color',
        	[
        	'label' => esc_html__('Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-name-style2 h5' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
        // Designation
        $this->add_control(
            'lcp_tatto_testi_style_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Typography', 'leadcapture'),
            'name'     => 'lcp_tatto_testi_style_postion_typography',
            'selector' => '{{WRAPPER}} .lc-test-name-style2 h6',
            ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_postion_color',
        	[
        	'label' => esc_html__('Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-name-style2 h6' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
        // Testimonal
        $this->add_control(
            'lcp_tatto_testi_style_testimonial',
            [
                'label'       => esc_html__( 'Testimonal', 'leadcapture' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Typography', 'leadcapture'),
            'name'     => 'lcp_tatto_testi_style_testimonial_typography',
            'selector' => '{{WRAPPER}} .lc-test-para-style2 p',
            ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_testimonial_color',
        	[
        	'label' => esc_html__('Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-para-style2 p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
        // Extra
        $this->add_control(
            'lcp_tatto_testi_style_extra',
            [
                'label'       => esc_html__( 'Extra', 'leadcapture' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_img_border_color',
        	[
        	'label' => esc_html__('Image Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-gallery-thumbs .swiper-slide.swiper-slide-active .swiper-slide-container > .lc-testimonial-img >img' => 'border-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_navigation_color',
        	[
        	'label' => esc_html__('Navigation Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-prev svg path' => 'fill: {{VALUE}}!important',
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-next svg path' => 'fill: {{VALUE}}!important',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_navigation_bgcolor',
        	[
        	'label' => esc_html__('Navigation Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-prev' => 'background-color: {{VALUE}}!important',
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-next' => 'background-color: {{VALUE}}!important',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_navigation_hcolor',
        	[
        	'label' => esc_html__('Navigation Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-prev:hover svg path' => 'fill: {{VALUE}}!important',
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-next:hover svg path' => 'fill: {{VALUE}}!important',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_navigation_hbgcolor',
        	[
        	'label' => esc_html__('Navigation Hover Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-prev:hover' => 'background-color: {{VALUE}}!important',
        	   '{{WRAPPER}} .lc-gallery-top > .swiper-button-next:hover' => 'background-color: {{VALUE}}!important',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_bullet_color',
        	[
        	'label' => esc_html__('Bullet Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-style2-testimonial-slider-wrapper > .swiper-pagination > .swiper-pagination-bullet' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lcp_tatto_testi_style_extra_bullet_acolor',
        	[
        	'label' => esc_html__('Bullet Active Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-style2-testimonial-slider-wrapper > .swiper-pagination > .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}}!important',
        	 ],
           ]
        );
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-style2-testimonial-slider-wrapper">
		        <div class="swiper lc-gallery-top">
                    <div class="swiper lc-gallery-thumbs">
                        <div class="swiper-wrapper">';
                            if(!empty($settings['lcp_tatto_testi_list'])){
                                foreach($settings['lcp_tatto_testi_list'] as $thumbs){
                                    echo '<div class="swiper-slide">
                                        <div class="swiper-slide-container">
                                            <div class="lc-testimonial-img">';
                                                if(!empty($thumbs['lcp_tatto_testi_list_image']['url'])){
                                                    echo '<img src="'.esc_url($thumbs['lcp_tatto_testi_list_image']['url']).'" />';
                                                }
                                            echo '</div>
                                        </div>
                                    </div>';
                                }
                            }
                        echo '</div>
                    </div>
                    <div class="swiper-wrapper">';
                        if(!empty($settings['lcp_tatto_testi_list'])){
                            foreach($settings['lcp_tatto_testi_list'] as $testi){
                                echo '<div class="swiper-slide">
                                    <div class="swiper-slide-container">
                                        <div class="lc-test-wrapper-style2">
                                            <div class="lc-test-img-style2">
                                                <div class="lc-test-name-style2">';
                                                    if($testi['lcp_tatto_testi_list_title']){
                                                        echo '<h5>'.esc_html($testi['lcp_tatto_testi_list_title']).'</h5>';
                                                    }
                                                    if($testi['lcp_tatto_testi_list_postion']){
                                                        echo '<h6>'.esc_html($testi['lcp_tatto_testi_list_postion']).'</h6>';
                                                    }
                                                echo '</div>
                                            </div>
                                            <div class="lc-test-para-style2">';
                                                if($testi['lcp_tatto_testi_list_testi']){
                                                    echo '<p>'.esc_html($testi['lcp_tatto_testi_list_testi']).'</p>';
                                                }
                                                echo '<div class="lc-quote-img-style2">
                                                    <img src="'.LEAD_CAPTURE_URL.'public/images/quote.png">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>';
                            }
                        }
                    echo '</div>
                    <div class="swiper-button-next">
                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 17 16" width="17"
                            height="16">
                            <title>Shape 3</title>
                            <path id="Shape 3" class="s0"
                                d="m2.8 7q0.1 0 0.1 0h9.2l-0.2-0.1q-0.3-0.1-0.5-0.4l-2.6-2.8c-0.3-0.3-0.4-0.9-0.1-1.3 0.3-0.4 0.9-0.5 1.3-0.2q0 0 0.1 0.1l4.6 5c0.4 0.4 0.4 1 0 1.4q0 0 0 0l-4.6 5c-0.4 0.4-1 0.4-1.3 0q-0.1 0-0.1-0.1c-0.3-0.4-0.2-1 0.1-1.3l2.6-2.8q0.2-0.2 0.5-0.4l0.2-0.1h-9.1c-0.5 0-0.9-0.3-1-0.8-0.1-0.6 0.3-1.1 0.8-1.2z" />
                        </svg>
                    </div>
                    <div class="swiper-button-prev">
                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 15" width="16"
                            height="15">
                            <title>Shape 3</title>
                            <path id="Shape 3" class="s0"
                                d="m14.1 7.4c-0.1 0.5-0.5 0.9-1 0.9h-9.1l0.3 0.1q0.2 0.2 0.4 0.4l2.6 2.7c0.3 0.4 0.4 0.9 0.1 1.4q0 0 0 0.1c-0.4 0.4-1 0.4-1.4 0l-4.6-5q0 0 0 0c-0.4-0.4-0.4-1.1 0-1.4l4.6-5q0.1-0.1 0.1-0.1c0.5-0.4 1-0.3 1.3 0.2 0.3 0.4 0.2 1-0.1 1.3l-2.6 2.8q-0.2 0.2-0.5 0.4l-0.2 0.1h9.2q0.1 0 0.1 0c0.6 0.1 0.9 0.6 0.8 1.1z" />
                        </svg>
                    </div>
                </div>
                <div class="swiper-pagination"></div>
		    </div>';
		}
	}
}